@@ -5,7 +5,7 @@ import logging
 import re
 from collections import defaultdict
 from copy import deepcopy
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, List
 
 from checkov.common.bridgecrew.integration_features.base_integration_feature import BaseIntegrationFeature
 from checkov.common.bridgecrew.platform_integration import bc_integration
@@ -29,6 +29,7 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
         self.platform_policy_parser = NXGraphCheckParser()
         self.policies_url = f"{self.bc_integration.api_url}/api/v1/policies/table/data"
         self.bc_cloned_checks: dict[str, list[dict[str, Any]]] = defaultdict(list)
+        self.policy_level_suppression: List[str] = []
 
     def is_valid(self) -> bool:
         return (
@@ -113,6 +114,7 @@ class CustomPoliciesIntegration(BaseIntegrationFeature):
                 new_record.severity = cloned_policy['severity']
                 new_record.check_name = cloned_policy['title']
                 records.append(new_record)
+        records = [record for record in records if record.bc_check_id not in self.policy_level_suppression]  # Filter out policy level suppressions after cloned policy is added
         return records
 
     def pre_runner(self, runner: _BaseRunner) -> None:
