@@ -40,3 +40,20 @@ def decompress_file_gzip_base64(compressed_file_body: str) -> bytes:
     except Exception:
         logging.exception("failed to extract package file")
         raise
+
+
+def compress_string_io_tar(string_io: io.StringIO) -> io.BytesIO:
+    file_io = io.BytesIO()
+    str_data = string_io.getvalue().encode('utf8')
+    bio = io.BytesIO(str_data)
+    try:
+        with tarfile.open(fileobj=file_io, mode='w:gz') as tar:
+            info = tar.tarinfo(name='logs_file.txt')
+            bio.seek(0)
+            info.size = string_io.tell()
+            tar.addfile(info, bio)
+        file_io.seek(0)
+        return file_io
+    except Exception:
+        logging.exception("failed to compress logging file")
+        raise
