@@ -134,28 +134,31 @@ class Runner(BaseRunner[None]):
         files: list[str] | None,
         excluded_paths: set[str],
         exclude_package_json: bool = True,
-        excluded_file_names: set[str] | None = None
+        excluded_file_names: set[str] | None = None,
+        extra_supported_package_files: set[str] | None = None
     ) -> set[Path]:
         excluded_file_names = excluded_file_names or set()
+        extra_supported_package_files = extra_supported_package_files or set()
         input_paths: set[Path] = set()
         if root_path:
             input_paths = {
                 file_path
                 for file_path in root_path.glob("**/*")
-                if file_path.name in SUPPORTED_PACKAGE_FILES and not any(p in file_path.parts for p in excluded_paths)
+                if file_path.name in SUPPORTED_PACKAGE_FILES.union(extra_supported_package_files) and not any(p in file_path.parts for p in excluded_paths)
             }
 
-            package_lock_parent_paths = set()
+            package_json_lock_parent_paths = set()
             if exclude_package_json:
-                # filter out package.json, if package-lock.json exists
-                package_lock_parent_paths = {
-                    file_path.parent for file_path in input_paths if file_path.name == "package-lock.json"
+                # filter out package.json, if package-lock.json or yarn.lock exists
+                package_json_lock_parent_paths = {
+                    file_path.parent for file_path in input_paths if
+                    file_path.name in {"package-lock.json", "yarn.lock"}
                 }
 
             input_paths = {
                 file_path
                 for file_path in input_paths
-                if (file_path.name != "package.json" or file_path.parent not in package_lock_parent_paths) and file_path.name not in excluded_file_names
+                if (file_path.name != "package.json" or file_path.parent not in package_json_lock_parent_paths) and file_path.name not in excluded_file_names
             }
 
         for file in files or []:
