@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 from typing import Any
 
-from checkov.common.models.enums import CheckCategories
+from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
 
 
@@ -19,9 +21,14 @@ class CosmosDBLocalAuthDisabled(BaseResourceValueCheck):
         categories = (CheckCategories.IAM,)
         super().__init__(name=description, id=id, categories=categories, supported_resources=supported_resources)
 
+    def scan_resource_conf(self, conf: dict[str, list[Any]]) -> CheckResult:
+        if conf.get("kind") == ["GlobalDocumentDB"]:
+            return super().scan_resource_conf(conf)
+        return CheckResult.UNKNOWN
+
     def get_inspected_key(self) -> str:
         return "local_authentication_disabled"
-        
+
     def get_expected_value(self) -> Any:
         return True
 
