@@ -12,12 +12,19 @@ class SecurityListIngressStateless(BaseResourceCheck):
 
     def scan_resource_conf(self, conf):
         if 'ingress_security_rules' in conf.keys():
-            self.evaluated_keys=['ingress_security_rules']
+            self.evaluated_keys = ['ingress_security_rules']
             rules = conf.get("ingress_security_rules")
+            is_list_syntax = False
+            if isinstance(rules[0], list):
+                # Old terraform oci provider version syntax for ingress_security_rules was a list instead of a block
+                rules = rules[0]
+                is_list_syntax = True
             for idx, rule in enumerate(rules):
                 if 'stateless' in rule.keys():
-                    if rule.get("stateless") != [True]:
-                        self.evaluated_keys = [f'ingress_security_rules/[{idx}]/stateless']
+                    stateless = rule.get("stateless")
+                    if stateless != [True] and stateless is not True:
+                        self.evaluated_keys = [f'ingress_security_rules/[{idx}]/stateless'] if is_list_syntax \
+                            else [f'ingress_security_rules/[0]/[{idx}]/stateless']
                         return CheckResult.FAILED
             return CheckResult.PASSED
 
