@@ -19,6 +19,7 @@ from checkov.common.util.parser_utils import get_abs_path, get_tf_definition_key
 from checkov.common.util.type_forcers import force_int
 from checkov.terraform.checks.utils.dependency_path_handler import unify_dependency_path
 from checkov.terraform.context_parsers.registry import parser_registry
+from checkov.terraform.graph_builder.foreach_handler import ForeachHandler, FOREACH_STRING
 from checkov.terraform.graph_builder.graph_components.block_types import BlockType
 from checkov.terraform.graph_builder.graph_components.blocks import TerraformBlock
 from checkov.terraform.graph_builder.graph_components.generic_resource_encryption import ENCRYPTION_BY_RESOURCE_TYPE
@@ -52,12 +53,18 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         self.dirname_cache: Dict[str, str] = {}
         self.vertices_by_module_dependency_by_name: Dict[Tuple[str, str], Dict[BlockType, Dict[str, List[int]]]] = defaultdict(lambda: defaultdict(lambda: defaultdict(list)))
         self.vertices_by_module_dependency: Dict[Tuple[str, str], Dict[BlockType, List[int]]] = defaultdict(lambda: defaultdict(list))
+        self.enable_foreach_handling = strtobool(os.getenv('CHECKOV_ENABLE_FOREACH_HANDLING', 'False'))
+        self.foreach_blocks: Dict[str, List[int]] = {BlockType.RESOURCE: [], BlockType.MODULE: []}
 
     def build_graph(self, render_variables: bool) -> None:
         self._create_vertices()
         logging.info(f"[TerraformLocalGraph] created {len(self.vertices)} vertices")
         self._build_edges()
         logging.info(f"[TerraformLocalGraph] created {len(self.edges)} edges")
+        if self.enable_foreach_handling:
+            foreach_handler = ForeachHandler(self)
+            foreach_handler.handle_foreach_rendering(self.foreach_blocks)
+            logging.info(f"[TerraformLocalGraph] finished handling foreach values with {len(self.vertices)} vertices and {len(self.edges)} edges")
 
         self.calculate_encryption_attribute(ENCRYPTION_BY_RESOURCE_TYPE)
         if render_variables:
@@ -92,6 +99,9 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             self.in_edges[i] = []
             self.out_edges[i] = []
 
+            if self.enable_foreach_handling and FOREACH_STRING in block.attributes and block.block_type in (BlockType.MODULE, BlockType.RESOURCE):
+                self.foreach_blocks[block.block_type].append(i)
+
     def _set_variables_values_from_modules(self) -> List[Undetermined]:
         undetermined_values: List[Undetermined] = []
         resources_types = self.get_resources_types_in_graph()
@@ -272,6 +282,14 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             if len(target_variables) == 1:
                 self._create_edge(target_variables[0], origin_node_index, "default", cross_variable_edges)
 
+    def reset_edges(self) -> None:
+        self.edges = []
+        self.out_edges = defaultdict(list)
+        self.in_edges = defaultdict(list)
+        for i in range(len(self.vertices)):
+            self.out_edges[i] = []
+            self.in_edges[i] = []
+
     def _build_cross_variable_edges(self):
         target_nodes_indexes = [v for v, referenced_vertices in self.out_edges.items() if
                                 self.vertices[v].block_type == BlockType.RESOURCE and any(
