@@ -1,17 +1,14 @@
 import logging
 import os
 import re
-from typing import Any, Union, Optional, List, Dict, Callable, TypeVar
+from typing import Any, Union, Optional, List, Dict, Callable, TypeVar, Tuple
 
-# condition ? true_val : false_val -> (condition, true_val, false_val)
 from checkov.common.util.type_forcers import force_int
 from checkov.common.util.parser_utils import find_var_blocks
 from checkov.terraform.graph_builder.variable_rendering.safe_eval_functions import evaluate
 
 T = TypeVar("T", str, int, bool)
 
-CONDITIONAL_EXPR = re.compile(r"([^\?]+)\?([^:]+)\:([^:]+)")
-
 # %{ some_text }
 DIRECTIVE_EXPR = re.compile(r"\%\{([^\}]*)\}")
 
@@ -127,20 +124,24 @@ def evaluate_conditional_expression(input_str: str) -> str:
     if variable_ref:
         input_str = variable_ref.groups()[0]
 
-    condition = re.match(CONDITIONAL_EXPR, input_str)
+    condition = find_conditional_expression_groups(input_str)
     while condition:
-        groups = condition.groups()
+        groups, start, end = condition
         if len(groups) != 3:
             return input_str
         evaluated_condition = evaluate_terraform(groups[0])
-        condition_substr = input_str[condition.start() : condition.end()]
-        if convert_to_bool(evaluated_condition):
+        condition_substr = input_str[start:end]
+        bool_evaluated_condition = convert_to_bool(evaluated_condition)
+        if bool_evaluated_condition is True:
             true_val = str(evaluate_terraform(groups[1])).strip()
             input_str = input_str.replace(condition_substr, true_val)
-        else:
+        elif bool_evaluated_condition is False:
             false_val = str(evaluate_terraform(groups[2])).strip()
             input_str = input_str.replace(condition_substr, false_val)
-        condition = re.match(CONDITIONAL_EXPR, input_str)
+        else:
+            # in case we didn't succeed to evaluate condition we shouldn't put any value.
+            break
+        condition = find_conditional_expression_groups(input_str)
 
     return input_str
 
@@ -248,8 +249,11 @@ def evaluate_map(input_str: str) -> str:
         for curly_match in all_curly_brackets:
             curly_start = curly_match["start"]
             curly_end = curly_match["end"]
-            replaced_matching_map = input_str[curly_start : curly_end + 1].replace("=", ":")
-            input_str = input_str.replace(input_str[curly_start : curly_end + 1], replaced_matching_map)
+            replaced_matching_map = ' ' + input_str[curly_start: curly_end + 1] + ' '
+            for i in range(1, len(replaced_matching_map) - 1):
+                if replaced_matching_map[i] == "=" and replaced_matching_map[i - 1] not in ["=", "!"] and replaced_matching_map[i + 1] != "=":
+                    replaced_matching_map = f'{replaced_matching_map[:i]}:{replaced_matching_map[i + 1:]}'
+            input_str = input_str.replace(input_str[curly_start : curly_end + 1], replaced_matching_map[1:-1])
 
     # find map access like {a: b}[a] and extract the right value - b
     all_square_brackets = find_brackets_pairs(input_str, "[", "]")
@@ -324,3 +328,76 @@ def find_brackets_pairs(input_str: str, starting: str, closing: str) -> List[Dic
         if end != -1 and end - start > 1:
             all_brackets.append({"start": start, "end": end})
     return all_brackets
+
+
+def find_conditional_expression_groups(input_str: str) -> Optional[Tuple[List[str], int, int]]:
+    """
+    from condition ? true_val : false_val return [condition, true_val, false_val]
+    """
+    if '?' not in input_str or ':' not in input_str:
+        return
+    if input_str.index('?') > input_str.rindex(':'):
+        return
+    brackets_pairs = {
+        '[': ']',
+        '{': '}',
+        '(': ')'
+    }
+    str_keys = {'\'', '"'}
+
+    stack = []
+    groups = []
+    end_stack = []
+
+    def _update_stack_if_needed(char, i):
+        # can be true only if the char in str_keys or in brackets_pairs.values()
+        if stack and stack[-1][0] == char:
+            stack.pop(len(stack) - 1)
+        elif char in brackets_pairs:
+            stack.append((brackets_pairs[char], i))
+        elif char in str_keys:
+            stack.append((char, i))
+
+    def _find_separator_index(separator: str, input_str: str, start: int, update_end_stack: bool = False) -> Optional[int]:
+        for i in range(start, len(input_str)):
+            char = input_str[i]
+            if char == separator:
+                if not stack or stack in end_stack:
+                    return i
+                if update_end_stack:
+                    end_stack.extend(stack)
+                    return i
+            _update_stack_if_needed(char, i)
+
+    # find first separator
+    first_separator = _find_separator_index('?', input_str, 0, update_end_stack=True)
+    if first_separator is None:
+        return
+    start = 0 if not stack else stack[-1][1]
+    groups.append(input_str[start:first_separator])
+
+    # find second separator
+    second_separator = _find_separator_index(':', input_str, first_separator)
+    if second_separator is None:
+        return
+    groups.append(input_str[first_separator + 1:second_separator])
+
+    if not stack:
+        groups.append(input_str[second_separator + 1:])
+        return groups, 0, len(input_str)
+
+    start = stack[-1][1]
+    end = len(input_str)
+    for i in range(second_separator + 1, len(input_str)):
+        char = input_str[i]
+        _update_stack_if_needed(char, i)
+        if not stack:
+            end = i + 1
+            break
+        if len(stack) + 1 == end_stack:
+            end = i
+            break
+
+    groups.append(input_str[second_separator + 1:end])
+
+    return groups, start, end
